@@ -14,7 +14,7 @@ typedef Eo Efl_Observable;
 #ifdef EFL_BETA_API_SUPPORT
 /** This type describes an observable touple
  *
- * @ingroup Efl
+ * @ingroup Efl_Observable_Tuple
  */
 typedef struct _Efl_Observable_Tuple
 {
@@ -81,7 +81,7 @@ EOAPI void efl_observable_observer_clean(Eo *obj, Efl_Observer *obs);
  *
  * @ingroup Efl_Observable
  */
-EOAPI Eina_Iterator *efl_observable_observers_iterator_new(Eo *obj, const char *key) EFL_TRANSFER_OWNERSHIP;
+EOAPI Eina_Iterator *efl_observable_observers_iterator_new(Eo *obj, const char *key) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Update all observers in a group by calling their update() method.
@@ -103,7 +103,7 @@ EOAPI void efl_observable_observers_update(Eo *obj, const char *key, void *data)
  *
  * @ingroup Efl_Observable
  */
-EOAPI Eina_Iterator *efl_observable_iterator_tuple_new(Eo *obj) EFL_TRANSFER_OWNERSHIP;
+EOAPI Eina_Iterator *efl_observable_iterator_tuple_new(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
